@@ -24,14 +24,10 @@ class directoryMapTab(QWidget):
         self.btn_run = QPushButton("Get Directory Map")
         self.btn_run.clicked.connect(self.start_map)
         # Output area
-        self.log = QTextEdit()
-        self.log.setReadOnly(True)
-        self.log.setLineWrapMode(QTextEdit.LineWrapMode.NoWrap)
+   
         self.layout().addWidget(QLabel("Results"))
-        self.layout().addWidget(self.log, stretch=2)
         self.list = QListWidget()
         self.list.itemDoubleClicked.connect(self.start_map)
         self.layout().addWidget(self.list, stretch=3)
         self._last_results = []
-        attach_textedit_to_logs(self.log, tail_file=get_log_file_path())
 directoryMapTab = initFuncs(directoryMapTab)
