@@ -14,12 +14,10 @@ class finderTab(QWidget):
 
 
         # Output area
-        set_self_log(self)
+        
         self.layout().addWidget(QLabel("Results"))
-        self.layout().addWidget(self.log, stretch=2)
         self.list = QListWidget()
         self.list.itemDoubleClicked.connect(self.open_one)
         self.layout().addWidget(self.list, stretch=3)
         self._last_results = []
-        attach_textedit_to_logs(self.log, tail_file=get_log_file_path())
 finderTab = initFuncs(finderTab)
